@@ -1,2 +1,2 @@
-from pygrass.interval.base import IntervalBase
-from pygrass.interval.formats import IntervalFormatBase, IntervalFile, BamFile
\ No newline at end of file
+from pygrass.interval.base import IntervalBase, SortedRandomBed3
+from pygrass.interval.formats import IntervalFormatBase, IntervalFile, BamFile
